@@ -8,6 +8,18 @@ macro_rules! ident_tok {
 }
 
 macro_rules! tok {
+    ("num") => {
+        swc_css_ast::Token::Num { .. }
+    };
+
+    ("dimension") => {
+        swc_css_ast::Token::Dimension { .. }
+    };
+
+    ("percent") => {
+        swc_css_ast::Token::Percent { .. }
+    };
+
     ("function") => {
         swc_css_ast::Token::Function { .. }
     };
@@ -24,6 +36,10 @@ macro_rules! tok {
         swc_css_ast::Token::BadStr { .. }
     };
 
+    ("url") => {
+        swc_css_ast::Token::Url { .. }
+    };
+
     ("bad-url") => {
         swc_css_ast::Token::BadUrl { .. }
     };
